#!/usr/bin/env python
import sys
import numpy as np
np.set_printoptions(threshold=sys.maxsize)
import mandelbrot_ext as mandel
import matplotlib.pyplot as plt
import juliaplot as jp
import time

#
#X = -0.748
#Y = 0.1
#R = 0.0014


def mandelbrot_loop(im_width, im_height, xwidth, yheight, xmin, ymin, nitmax):
    zabsmax = 2.0
    maxval=0;
    mm = np.zeros((im_width * im_height))
    for i in range(im_width * im_height):
        # i = ix * im_width + iy
        ix = int(i/im_width)
        iy = i - ix * im_width
        nit = 0
        c = complex(xmin + float(ix)*xwidth/im_width ,
                    ymin + float(iy)*yheight/im_height)
        z = 0.0j;
        # Do the iterations
        mm[i] = mandel.calcz(z,c,zabsmax)
        if mm[i] == 1.0:
            mm[i] = 0.0;
        else:
            mm[i] *= 1000.0;
    return mm.reshape(im_width,im_height)






if __name__ == '__main__':
#    if len(sys.argv)>1:
#        file = sys.argv[1]
    #X = -0.748
    #Y = 0.1
    #R = 0.0014
    #
    #X = -0.722
    #Y = 0.246
    #R = 0.019
    #
    X = -0.7453
    Y = 0.1127
    R = 0.00065
    print("Mandelbrot set fractal generator\n")
    im_width = 1000
    im_height = 1000
    ymin,ymax = X-R, X+R
    xmin, xmax = Y-R, Y+R
    #xmin,xmax = -1.2, 1.2
    xwidth = xmax-xmin
    #ymin, ymax = -1.8, 0.6
    #ymin, ymax = 0.4, 0.6
    yheight = ymax - ymin
    nitmax = 10000
    zabsmax = 2.0
    title="Mandelbrot set fractal generator"
    tic = time.time()
    mm = mandelbrot_loop(im_width, im_height, yheight, xwidth, ymin, xmin, nitmax)
    toc = time.time()
    #xxx=set(mm.flatten().tolist())
    #print (xxx)
    fig, ax = jp.plot(mm)
    jp.plotlabels(fig, ax, im_width, im_height, xmin,xmax,xwidth, ymin, ymax, yheight)    
    plt.show()
    print("time",toc-tic)
